==> jc-1.4.0.tar.gz: javax/print/attribute/TextSyntax.h <==
// public abstract class javax.print.attribute.TextSyntax

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2c49b1290ea91885 javax_print_attribute_TextSyntax

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_TextSyntax_H_
#define _JC_javax_print_attribute_TextSyntax_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_javax_print_attribute_TextSyntax$sub_refs	_jc_javax_print_attribute_TextSyntax$sub_refs;
typedef struct _jc_javax_print_attribute_TextSyntax$sub_nonrefs	_jc_javax_print_attribute_TextSyntax$sub_nonrefs;
typedef struct _jc_javax_print_attribute_TextSyntax$refs	_jc_javax_print_attribute_TextSyntax$refs;
typedef struct _jc_javax_print_attribute_TextSyntax$nonrefs	_jc_javax_print_attribute_TextSyntax$nonrefs;
typedef struct _jc_javax_print_attribute_TextSyntax$object	_jc_javax_print_attribute_TextSyntax$object;

typedef struct _jc_javax_print_attribute_TextSyntax$fields_struct	_jc_javax_print_attribute_TextSyntax$fields_struct;
typedef const struct _jc_javax_print_attribute_TextSyntax$vmethods	_jc_javax_print_attribute_TextSyntax$vmethods;
typedef const struct _jc_javax_print_attribute_TextSyntax$vtable	_jc_javax_print_attribute_TextSyntax$vtable;
typedef const struct _jc_javax_print_attribute_TextSyntax$vtype	_jc_javax_print_attribute_TextSyntax$vtype;

// Class fields structure
struct _jc_javax_print_attribute_TextSyntax$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_TextSyntax$fields_struct _jc_javax_print_attribute_TextSyntax$class_fields;

// Constructors
extern void _jc_javax_print_attribute_TextSyntax$method$_init$cc9f9d14d2541299(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *);

// Virtual methods
extern jboolean _jc_javax_print_attribute_TextSyntax$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_util_Locale$object *_jc_javax_print_attribute_TextSyntax$method$getLocale$0f16f3de840c0c1e(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_TextSyntax$method$getValue$70c0a0897e30f88c(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *);
extern jint _jc_javax_print_attribute_TextSyntax$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_TextSyntax$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_TextSyntax$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_TextSyntax$method_info$getLocale$0f16f3de840c0c1e;
extern _jc_method _jc_javax_print_attribute_TextSyntax$method_info$getValue$70c0a0897e30f88c;
extern _jc_method _jc_javax_print_attribute_TextSyntax$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_print_attribute_TextSyntax$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_print_attribute_TextSyntax$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_util_Locale$object	*(*getLocale$0f16f3de840c0c1e)(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *);
	struct _jc_java_lang_String$object	*(*getValue$70c0a0897e30f88c)(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *);
};

// Vtable
struct _jc_javax_print_attribute_TextSyntax$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_TextSyntax$vmethods	javax_print_attribute_TextSyntax;
};

// Vtype
struct _jc_javax_print_attribute_TextSyntax$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_TextSyntax$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_TextSyntax$sub_refs {
	struct _jc_java_lang_String$object	*value;
	struct _jc_java_util_Locale$object	*locale;
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_TextSyntax$refs {
    _jc_javax_print_attribute_TextSyntax$sub_refs	javax_print_attribute_TextSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_TextSyntax$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_TextSyntax$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_TextSyntax$sub_nonrefs	javax_print_attribute_TextSyntax;
};

// Object instance structure
struct _jc_javax_print_attribute_TextSyntax$object {
	_jc_javax_print_attribute_TextSyntax$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_TextSyntax$vtype	*vtype;
	_jc_javax_print_attribute_TextSyntax$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_TextSyntax$vtype _jc_javax_print_attribute_TextSyntax$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_TextSyntax, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_TextSyntax$class_object;

#endif	/* _JC_javax_print_attribute_TextSyntax_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/TextSyntax.h <==
// public abstract class javax.print.attribute.TextSyntax

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2c49b1290ea91885 javax_print_attribute_TextSyntax

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_TextSyntax_H_
#define _JC_javax_print_attribute_TextSyntax_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_javax_print_attribute_TextSyntax$sub_refs	_jc_javax_print_attribute_TextSyntax$sub_refs;
typedef struct _jc_javax_print_attribute_TextSyntax$sub_nonrefs	_jc_javax_print_attribute_TextSyntax$sub_nonrefs;
typedef struct _jc_javax_print_attribute_TextSyntax$refs	_jc_javax_print_attribute_TextSyntax$refs;
typedef struct _jc_javax_print_attribute_TextSyntax$nonrefs	_jc_javax_print_attribute_TextSyntax$nonrefs;
typedef struct _jc_javax_print_attribute_TextSyntax$object	_jc_javax_print_attribute_TextSyntax$object;

typedef struct _jc_javax_print_attribute_TextSyntax$fields_struct	_jc_javax_print_attribute_TextSyntax$fields_struct;
typedef const struct _jc_javax_print_attribute_TextSyntax$vmethods	_jc_javax_print_attribute_TextSyntax$vmethods;
typedef const struct _jc_javax_print_attribute_TextSyntax$vtable	_jc_javax_print_attribute_TextSyntax$vtable;
typedef const struct _jc_javax_print_attribute_TextSyntax$vtype	_jc_javax_print_attribute_TextSyntax$vtype;

// Class fields structure
struct _jc_javax_print_attribute_TextSyntax$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_TextSyntax$fields_struct _jc_javax_print_attribute_TextSyntax$class_fields;

// Constructors
extern void _jc_javax_print_attribute_TextSyntax$method$_init$cc9f9d14d2541299(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_print_attribute_TextSyntax$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_Locale$object *_jc_javax_print_attribute_TextSyntax$method$getLocale$0f16f3de840c0c1e(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_TextSyntax$method$getValue$70c0a0897e30f88c(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_print_attribute_TextSyntax$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_TextSyntax$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_TextSyntax$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_TextSyntax$method_info$getLocale$0f16f3de840c0c1e;
extern _jc_method _jc_javax_print_attribute_TextSyntax$method_info$getValue$70c0a0897e30f88c;
extern _jc_method _jc_javax_print_attribute_TextSyntax$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_print_attribute_TextSyntax$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_print_attribute_TextSyntax$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_Locale$object	*(*getLocale$0f16f3de840c0c1e)(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getValue$70c0a0897e30f88c)(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_print_attribute_TextSyntax$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_TextSyntax$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_TextSyntax$vmethods	javax_print_attribute_TextSyntax;
};

// Vtype
struct _jc_javax_print_attribute_TextSyntax$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_TextSyntax$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_TextSyntax$sub_refs {
	struct _jc_java_lang_String$object	*value;
	struct _jc_java_util_Locale$object	*locale;
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_TextSyntax$refs {
    _jc_javax_print_attribute_TextSyntax$sub_refs	javax_print_attribute_TextSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_TextSyntax$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_TextSyntax$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_TextSyntax$sub_nonrefs	javax_print_attribute_TextSyntax;
};

// Object instance structure
struct _jc_javax_print_attribute_TextSyntax$object {
	_jc_javax_print_attribute_TextSyntax$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_TextSyntax$vtype	*vtype;
	_jc_javax_print_attribute_TextSyntax$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_TextSyntax$vtype _jc_javax_print_attribute_TextSyntax$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_TextSyntax, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_TextSyntax$class_object;

#endif	/* _JC_javax_print_attribute_TextSyntax_H_ */
